<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>Щойно</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>Одне нове повідомлення</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 хвилин тому</translation>
    </message>
</context>
</TS>